@@ -77,9 +77,8 @@ perl_object * my_parse_list_strings(List<String> list) {
 perl_object * my_parse_table(THD * thd, st_select_lex * select_lex, perl_object * query_perl, perl_object * join_perl, st_table_list * table) {
 
 	perl_object * table_perl = my_parse_create_array();
-	perl_object * table_perl_ref = my_parse_bless(table_perl, MYPARSE_ITEM_CLASS);
 
-	if (table->alias) {
+	if (table->alias) {	
 		my_parse_set_array( table_perl, MYPARSE_ITEM_ALIAS, (void *) table->alias, MYPARSE_ARRAY_STRING);
 	}
 
@@ -150,6 +149,7 @@ perl_object * my_parse_table(THD * thd, st_select_lex * select_lex, perl_object
 
 	if (table->nested_join) {
 		perl_object * join_items_perl = my_parse_tables_obj( thd, select_lex, query_perl, &table->nested_join->join_list);
+		my_parse_free_array(table_perl);
 		return join_items_perl;
 	} else if (table->derived) {
                 my_parse_set_array( table_perl, MYPARSE_ITEM_ITEM_TYPE, (void *) "SUBSELECT_ITEM", MYPARSE_ARRAY_STRING);
@@ -159,11 +159,11 @@ perl_object * my_parse_table(THD * thd, st_select_lex * select_lex, perl_object
 
 		perl_object * subselect_perl = my_parse_inner(unit->thd, sl, 1);
 		my_parse_set_array( table_perl, MYPARSE_ITEM_SUBSELECT_QUERY, subselect_perl, MYPARSE_ARRAY_REF);
-		return table_perl_ref;
 	} else {
 		my_parse_set_array( table_perl, MYPARSE_ITEM_ITEM_TYPE, (void *) "TABLE_ITEM", MYPARSE_ARRAY_STRING);
 	}
 
+	perl_object * table_perl_ref = my_parse_bless(table_perl, MYPARSE_ITEM_CLASS);
 	return table_perl_ref;
 }
 
@@ -273,10 +273,11 @@ perl_object * my_parse_item(THD * thd, Item * item) {
 	
 	char item_value_str[255];
 	void * item_value_ref = NULL;
+	size_t item_value_len = 0;
 	perl_object * args_perl = my_parse_create_array();
 	bool has_args = 0;
 
-	if (item->name) {	
+	if ((item->name) && (item->is_autogenerated_name == FALSE)) {	
 		my_parse_set_array( perl_item, MYPARSE_ITEM_ALIAS, (void *) item->name, MYPARSE_ARRAY_STRING);
 	}
 
@@ -296,6 +297,7 @@ perl_object * my_parse_item(THD * thd, Item * item) {
 				my_parse_set_array( perl_item, MYPARSE_ITEM_CHARSET, (void *) charset->csname, MYPARSE_ARRAY_STRING);
 			}
 		}
+		item_value_len = item->str_value.length();
 		item_value_ref = (void *) item->str_value.ptr();
 	} else if (item->type() == Item::INT_ITEM) {
 		snprintf( item_value_str, 255, "%llu", item->val_int());
@@ -632,7 +634,16 @@ perl_object * my_parse_item(THD * thd, Item * item) {
 	}
 
 	if (item_value_ref) {
-		my_parse_set_array( perl_item, MYPARSE_ITEM_VALUE, item_value_ref, MYPARSE_ARRAY_STRING);
+		if (item_value_len) {
+			/* If we know the length, we construct the perl string ourselves
+				so that the length is reported correctly and any NULL
+				characters inside the string do not terminate it
+			*/
+			perl_object * string_perl = my_parse_create_string( (char *) item_value_ref, item_value_len);
+			my_parse_set_array( perl_item, MYPARSE_ITEM_VALUE, string_perl, MYPARSE_ARRAY_SV);
+		} else {
+			my_parse_set_array( perl_item, MYPARSE_ITEM_VALUE, item_value_ref, MYPARSE_ARRAY_STRING);
+		}
 	}
 
 	return perl_item_ref;
@@ -690,7 +701,7 @@ perl_object * my_parse_outer(perl_object * parser, char * db, char * query) {
 		query_perl_ref = my_parse_inner( thd, &lex->select_lex, 0);
 	}
 
-	query_cache_abort(&thd->net);
+/*	query_cache_abort(&thd->net);	*/
 	lex->unit.cleanup();
 	close_thread_tables(thd);
 	thd->end_statement();
